import 'liveConsultation.m.dart';
import 'identityApply.m.dart';
import 'notification.m.dart';

import 'package:fis_jsonrpc/utils.dart';

enum UserInfoStateEnum {
	Nonactivated,
	Activated,
}

class LoginLockInfoDTO {
	DateTime? loginDate;
	int times;

	LoginLockInfoDTO({
		this.loginDate,
		this.times = 0,
	});

	factory LoginLockInfoDTO.fromJson(Map<String, dynamic> map) {
		return LoginLockInfoDTO( 
			loginDate: map['LoginDate'] != null ? DateTime.parse(map['LoginDate']) : null,
			times: map['Times'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(loginDate != null)
			map['LoginDate'] = JsonRpcUtils.dateFormat(loginDate!);
		map['Times'] = times;
		return map;
	}
}

class UserDTO extends UserBaseDTO{
	String? phone;
	String? email;
	String? nickName;
	String? fullName;
	String? organizationCode;
	String? organizationName;
	String? rootOrganizationCode;
	String? rootOrganizationName;
	List<String >? authorityGroups;
	List<String >? bindDevices;
	String? lastIP;
	int logintimes;
	UserInfoStateEnum userState;
	List<String >? roleCodes;
	List<String >? rankCodes;
	List<String >? positionCodes;
	ApplyStateEnum applyState;
	String? rankName;
	String? positionName;
	bool isDirector;
	List<String >? fieldList;
	List<String >? deletePatientCodes;
	bool isBatchExportDiagnoseData;
	String? bindAssistantUserCode;
	String? bindAssistantDoctorUserCode;
	LoginLockInfoDTO? loginLockInfo;
	String? signature;
	String? language;
	bool enableReportLabel;

	UserDTO({
		this.phone,
		this.email,
		this.nickName,
		this.fullName,
		this.organizationCode,
		this.organizationName,
		this.rootOrganizationCode,
		this.rootOrganizationName,
		this.authorityGroups,
		this.bindDevices,
		this.lastIP,
		this.logintimes = 0,
		this.userState = UserInfoStateEnum.Nonactivated,
		this.roleCodes,
		this.rankCodes,
		this.positionCodes,
		this.applyState = ApplyStateEnum.NotApply,
		this.rankName,
		this.positionName,
		this.isDirector = false,
		this.fieldList,
		this.deletePatientCodes,
		this.isBatchExportDiagnoseData = false,
		this.bindAssistantUserCode,
		this.bindAssistantDoctorUserCode,
		this.loginLockInfo,
		this.signature,
		this.language,
		this.enableReportLabel = false,
		String? userCode,
		String? userName,
		String? headImageUrl,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			userCode: userCode,
			userName: userName,
			headImageUrl: headImageUrl,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserDTO.fromJson(Map<String, dynamic> map) {
		return UserDTO( 
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			rootOrganizationCode: map['RootOrganizationCode'],
			rootOrganizationName: map['RootOrganizationName'],
			authorityGroups: map['AuthorityGroups'] != null ? map['AuthorityGroups'].cast<String>().toList() : null,
			bindDevices: map['BindDevices'] != null ? map['BindDevices'].cast<String>().toList() : null,
			lastIP: map['LastIP'],
			logintimes: map['Logintimes'],
			userState: UserInfoStateEnum.values.firstWhere((e) => e.index == map['UserState']),
			roleCodes: map['RoleCodes'] != null ? map['RoleCodes'].cast<String>().toList() : null,
			rankCodes: map['RankCodes'] != null ? map['RankCodes'].cast<String>().toList() : null,
			positionCodes: map['PositionCodes'] != null ? map['PositionCodes'].cast<String>().toList() : null,
			applyState: ApplyStateEnum.values.firstWhere((e) => e.index == map['ApplyState']),
			rankName: map['RankName'],
			positionName: map['PositionName'],
			isDirector: map['IsDirector'],
			fieldList: map['FieldList'] != null ? map['FieldList'].cast<String>().toList() : null,
			deletePatientCodes: map['DeletePatientCodes'] != null ? map['DeletePatientCodes'].cast<String>().toList() : null,
			isBatchExportDiagnoseData: map['IsBatchExportDiagnoseData'],
			bindAssistantUserCode: map['BindAssistantUserCode'],
			bindAssistantDoctorUserCode: map['BindAssistantDoctorUserCode'],
			loginLockInfo: map['LoginLockInfo'] != null ? LoginLockInfoDTO.fromJson(map['LoginLockInfo']) : null,
			signature: map['Signature'],
			language: map['Language'],
			enableReportLabel: map['EnableReportLabel'],
			userCode: map['UserCode'],
			userName: map['UserName'],
			headImageUrl: map['HeadImageUrl'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(phone != null)
			map['Phone'] = phone;
		if(email != null)
			map['Email'] = email;
		if(nickName != null)
			map['NickName'] = nickName;
		if(fullName != null)
			map['FullName'] = fullName;
		if(organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if(organizationName != null)
			map['OrganizationName'] = organizationName;
		if(rootOrganizationCode != null)
			map['RootOrganizationCode'] = rootOrganizationCode;
		if(rootOrganizationName != null)
			map['RootOrganizationName'] = rootOrganizationName;
		if(authorityGroups != null)
			map['AuthorityGroups'] = authorityGroups;
		if(bindDevices != null)
			map['BindDevices'] = bindDevices;
		if(lastIP != null)
			map['LastIP'] = lastIP;
		map['Logintimes'] = logintimes;
		map['UserState'] = userState.index;
		if(roleCodes != null)
			map['RoleCodes'] = roleCodes;
		if(rankCodes != null)
			map['RankCodes'] = rankCodes;
		if(positionCodes != null)
			map['PositionCodes'] = positionCodes;
		map['ApplyState'] = applyState.index;
		if(rankName != null)
			map['RankName'] = rankName;
		if(positionName != null)
			map['PositionName'] = positionName;
		map['IsDirector'] = isDirector;
		if(fieldList != null)
			map['FieldList'] = fieldList;
		if(deletePatientCodes != null)
			map['DeletePatientCodes'] = deletePatientCodes;
		map['IsBatchExportDiagnoseData'] = isBatchExportDiagnoseData;
		if(bindAssistantUserCode != null)
			map['BindAssistantUserCode'] = bindAssistantUserCode;
		if(bindAssistantDoctorUserCode != null)
			map['BindAssistantDoctorUserCode'] = bindAssistantDoctorUserCode;
		if(loginLockInfo != null)
			map['LoginLockInfo'] = loginLockInfo;
		if(signature != null)
			map['Signature'] = signature;
		if(language != null)
			map['Language'] = language;
		map['EnableReportLabel'] = enableReportLabel;
		return map;
	}
}

class GetUserInfoRequest extends TokenRequest{

	GetUserInfoRequest({
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserInfoRequest.fromJson(Map<String, dynamic> map) {
		return GetUserInfoRequest( 
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		return map;
	}
}

class AlterUserInfoRequest extends TokenRequest{
	String? phone;
	String? email;
	String? nickName;
	String? fullName;
	String? headImageUrl;
	String? organizationCode;
	String? extensionData;

	AlterUserInfoRequest({
		this.phone,
		this.email,
		this.nickName,
		this.fullName,
		this.headImageUrl,
		this.organizationCode,
		this.extensionData,
		String? token,
	}) : super(
			token: token,
		);

	factory AlterUserInfoRequest.fromJson(Map<String, dynamic> map) {
		return AlterUserInfoRequest( 
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			headImageUrl: map['HeadImageUrl'],
			organizationCode: map['OrganizationCode'],
			extensionData: map['ExtensionData'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(phone != null)
			map['Phone'] = phone;
		if(email != null)
			map['Email'] = email;
		if(nickName != null)
			map['NickName'] = nickName;
		if(fullName != null)
			map['FullName'] = fullName;
		if(headImageUrl != null)
			map['HeadImageUrl'] = headImageUrl;
		if(organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if(extensionData != null)
			map['ExtensionData'] = extensionData;
		return map;
	}
}

class UserExtendDTO extends UserDTO{
	String? roleName;

	UserExtendDTO({
		this.roleName,
		String? phone,
		String? email,
		String? nickName,
		String? fullName,
		String? organizationCode,
		String? organizationName,
		String? rootOrganizationCode,
		String? rootOrganizationName,
		List<String >? authorityGroups,
		List<String >? bindDevices,
		String? lastIP,
		int logintimes = 0,
		UserInfoStateEnum userState = UserInfoStateEnum.Nonactivated,
		List<String >? roleCodes,
		List<String >? rankCodes,
		List<String >? positionCodes,
		ApplyStateEnum applyState = ApplyStateEnum.NotApply,
		String? rankName,
		String? positionName,
		bool isDirector = false,
		List<String >? fieldList,
		List<String >? deletePatientCodes,
		bool isBatchExportDiagnoseData = false,
		String? bindAssistantUserCode,
		String? bindAssistantDoctorUserCode,
		LoginLockInfoDTO? loginLockInfo,
		String? signature,
		String? language,
		bool enableReportLabel = false,
		String? userCode,
		String? userName,
		String? headImageUrl,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			phone: phone,
			email: email,
			nickName: nickName,
			fullName: fullName,
			organizationCode: organizationCode,
			organizationName: organizationName,
			rootOrganizationCode: rootOrganizationCode,
			rootOrganizationName: rootOrganizationName,
			authorityGroups: authorityGroups,
			bindDevices: bindDevices,
			lastIP: lastIP,
			logintimes: logintimes,
			userState: userState,
			roleCodes: roleCodes,
			rankCodes: rankCodes,
			positionCodes: positionCodes,
			applyState: applyState,
			rankName: rankName,
			positionName: positionName,
			isDirector: isDirector,
			fieldList: fieldList,
			deletePatientCodes: deletePatientCodes,
			isBatchExportDiagnoseData: isBatchExportDiagnoseData,
			bindAssistantUserCode: bindAssistantUserCode,
			bindAssistantDoctorUserCode: bindAssistantDoctorUserCode,
			loginLockInfo: loginLockInfo,
			signature: signature,
			language: language,
			enableReportLabel: enableReportLabel,
			userCode: userCode,
			userName: userName,
			headImageUrl: headImageUrl,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserExtendDTO.fromJson(Map<String, dynamic> map) {
		return UserExtendDTO( 
			roleName: map['RoleName'],
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			rootOrganizationCode: map['RootOrganizationCode'],
			rootOrganizationName: map['RootOrganizationName'],
			authorityGroups: map['AuthorityGroups'] != null ? map['AuthorityGroups'].cast<String>().toList() : null,
			bindDevices: map['BindDevices'] != null ? map['BindDevices'].cast<String>().toList() : null,
			lastIP: map['LastIP'],
			logintimes: map['Logintimes'],
			userState: UserInfoStateEnum.values.firstWhere((e) => e.index == map['UserState']),
			roleCodes: map['RoleCodes'] != null ? map['RoleCodes'].cast<String>().toList() : null,
			rankCodes: map['RankCodes'] != null ? map['RankCodes'].cast<String>().toList() : null,
			positionCodes: map['PositionCodes'] != null ? map['PositionCodes'].cast<String>().toList() : null,
			applyState: ApplyStateEnum.values.firstWhere((e) => e.index == map['ApplyState']),
			rankName: map['RankName'],
			positionName: map['PositionName'],
			isDirector: map['IsDirector'],
			fieldList: map['FieldList'] != null ? map['FieldList'].cast<String>().toList() : null,
			deletePatientCodes: map['DeletePatientCodes'] != null ? map['DeletePatientCodes'].cast<String>().toList() : null,
			isBatchExportDiagnoseData: map['IsBatchExportDiagnoseData'],
			bindAssistantUserCode: map['BindAssistantUserCode'],
			bindAssistantDoctorUserCode: map['BindAssistantDoctorUserCode'],
			loginLockInfo: map['LoginLockInfo'] != null ? LoginLockInfoDTO.fromJson(map['LoginLockInfo']) : null,
			signature: map['Signature'],
			language: map['Language'],
			enableReportLabel: map['EnableReportLabel'],
			userCode: map['UserCode'],
			userName: map['UserName'],
			headImageUrl: map['HeadImageUrl'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(roleName != null)
			map['RoleName'] = roleName;
		return map;
	}
}

enum OrganizationQueryTypeEnum {
	Wait,
	Single,
	AllDep,
	All,
}

class GetUserListRequest extends TokenRequest{
	String? keyword;
	OrganizationQueryTypeEnum organizationQueryType;
	String? organizationCode;
	String? rankCode;
	String? positionCode;
	bool exceptSelf;
	String? language;

	GetUserListRequest({
		this.keyword,
		this.organizationQueryType = OrganizationQueryTypeEnum.Wait,
		this.organizationCode,
		this.rankCode,
		this.positionCode,
		this.exceptSelf = false,
		this.language,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserListRequest.fromJson(Map<String, dynamic> map) {
		return GetUserListRequest( 
			keyword: map['Keyword'],
			organizationQueryType: OrganizationQueryTypeEnum.values.firstWhere((e) => e.index == map['OrganizationQueryType']),
			organizationCode: map['OrganizationCode'],
			rankCode: map['RankCode'],
			positionCode: map['PositionCode'],
			exceptSelf: map['ExceptSelf'],
			language: map['Language'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(keyword != null)
			map['Keyword'] = keyword;
		map['OrganizationQueryType'] = organizationQueryType.index;
		if(organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		if(rankCode != null)
			map['RankCode'] = rankCode;
		if(positionCode != null)
			map['PositionCode'] = positionCode;
		map['ExceptSelf'] = exceptSelf;
		if(language != null)
			map['Language'] = language;
		return map;
	}
}

class RemoveUsersFromOrganizationRequest extends TokenRequest{
	List<String >? userCodes;

	RemoveUsersFromOrganizationRequest({
		this.userCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory RemoveUsersFromOrganizationRequest.fromJson(Map<String, dynamic> map) {
		return RemoveUsersFromOrganizationRequest( 
			userCodes: map['UserCodes'] != null ? map['UserCodes'].cast<String>().toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(userCodes != null)
			map['UserCodes'] = userCodes;
		return map;
	}
}

class SetUserOrganizationInfoRequest extends TokenRequest{
	String? userCode;
	List<String >? roleCodes;
	List<String >? rankCodes;
	List<String >? positionCodes;
	String? organizationCode;

	SetUserOrganizationInfoRequest({
		this.userCode,
		this.roleCodes,
		this.rankCodes,
		this.positionCodes,
		this.organizationCode,
		String? token,
	}) : super(
			token: token,
		);

	factory SetUserOrganizationInfoRequest.fromJson(Map<String, dynamic> map) {
		return SetUserOrganizationInfoRequest( 
			userCode: map['UserCode'],
			roleCodes: map['RoleCodes'] != null ? map['RoleCodes'].cast<String>().toList() : null,
			rankCodes: map['RankCodes'] != null ? map['RankCodes'].cast<String>().toList() : null,
			positionCodes: map['PositionCodes'] != null ? map['PositionCodes'].cast<String>().toList() : null,
			organizationCode: map['OrganizationCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(userCode != null)
			map['UserCode'] = userCode;
		if(roleCodes != null)
			map['RoleCodes'] = roleCodes;
		if(rankCodes != null)
			map['RankCodes'] = rankCodes;
		if(positionCodes != null)
			map['PositionCodes'] = positionCodes;
		if(organizationCode != null)
			map['OrganizationCode'] = organizationCode;
		return map;
	}
}

class AlterPersonInfoRequest {
	String? token;
	String? nickName;
	String? headImageUrl;

	AlterPersonInfoRequest({
		this.token,
		this.nickName,
		this.headImageUrl,
	});

	factory AlterPersonInfoRequest.fromJson(Map<String, dynamic> map) {
		return AlterPersonInfoRequest( 
			token: map['Token'],
			nickName: map['NickName'],
			headImageUrl: map['HeadImageUrl'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(token != null)
			map['Token'] = token;
		if(nickName != null)
			map['NickName'] = nickName;
		if(headImageUrl != null)
			map['HeadImageUrl'] = headImageUrl;
		return map;
	}
}

class ShareDeviceUserDTO extends BaseDTO{
	String? userCode;
	String? fullName;
	String? phone;
	String? headImageUrl;
	List<String >? rankNames;
	String? rootOrganizationCode;
	String? rootOrganizationName;

	ShareDeviceUserDTO({
		this.userCode,
		this.fullName,
		this.phone,
		this.headImageUrl,
		this.rankNames,
		this.rootOrganizationCode,
		this.rootOrganizationName,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			createTime: createTime,
			updateTime: updateTime,
		);

	factory ShareDeviceUserDTO.fromJson(Map<String, dynamic> map) {
		return ShareDeviceUserDTO( 
			userCode: map['UserCode'],
			fullName: map['FullName'],
			phone: map['Phone'],
			headImageUrl: map['HeadImageUrl'],
			rankNames: map['RankNames'] != null ? map['RankNames'].cast<String>().toList() : null,
			rootOrganizationCode: map['RootOrganizationCode'],
			rootOrganizationName: map['RootOrganizationName'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(userCode != null)
			map['UserCode'] = userCode;
		if(fullName != null)
			map['FullName'] = fullName;
		if(phone != null)
			map['Phone'] = phone;
		if(headImageUrl != null)
			map['HeadImageUrl'] = headImageUrl;
		if(rankNames != null)
			map['RankNames'] = rankNames;
		if(rootOrganizationCode != null)
			map['RootOrganizationCode'] = rootOrganizationCode;
		if(rootOrganizationName != null)
			map['RootOrganizationName'] = rootOrganizationName;
		return map;
	}
}

class GetShareDeviceUsersPageRequest extends PageRequest{
	String? deviceCode;

	GetShareDeviceUsersPageRequest({
		this.deviceCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory GetShareDeviceUsersPageRequest.fromJson(Map<String, dynamic> map) {
		return GetShareDeviceUsersPageRequest( 
			deviceCode: map['DeviceCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(deviceCode != null)
			map['DeviceCode'] = deviceCode;
		return map;
	}
}

class UserFeatureInfoResult {
	String? featureCode;
	String? featureName;
	String? fatherCode;
	String? uniqueCode;

	UserFeatureInfoResult({
		this.featureCode,
		this.featureName,
		this.fatherCode,
		this.uniqueCode,
	});

	factory UserFeatureInfoResult.fromJson(Map<String, dynamic> map) {
		return UserFeatureInfoResult( 
			featureCode: map['FeatureCode'],
			featureName: map['FeatureName'],
			fatherCode: map['FatherCode'],
			uniqueCode: map['UniqueCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(featureCode != null)
			map['FeatureCode'] = featureCode;
		if(featureName != null)
			map['FeatureName'] = featureName;
		if(fatherCode != null)
			map['FatherCode'] = fatherCode;
		if(uniqueCode != null)
			map['UniqueCode'] = uniqueCode;
		return map;
	}
}

class UserInfoByCodeDTO extends UserDTO{
	String? bindAssistantUserName;
	String? bindAssistantDoctorUserName;

	UserInfoByCodeDTO({
		this.bindAssistantUserName,
		this.bindAssistantDoctorUserName,
		String? phone,
		String? email,
		String? nickName,
		String? fullName,
		String? organizationCode,
		String? organizationName,
		String? rootOrganizationCode,
		String? rootOrganizationName,
		List<String >? authorityGroups,
		List<String >? bindDevices,
		String? lastIP,
		int logintimes = 0,
		UserInfoStateEnum userState = UserInfoStateEnum.Nonactivated,
		List<String >? roleCodes,
		List<String >? rankCodes,
		List<String >? positionCodes,
		ApplyStateEnum applyState = ApplyStateEnum.NotApply,
		String? rankName,
		String? positionName,
		bool isDirector = false,
		List<String >? fieldList,
		List<String >? deletePatientCodes,
		bool isBatchExportDiagnoseData = false,
		String? bindAssistantUserCode,
		String? bindAssistantDoctorUserCode,
		LoginLockInfoDTO? loginLockInfo,
		String? signature,
		String? language,
		bool enableReportLabel = false,
		String? userCode,
		String? userName,
		String? headImageUrl,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			phone: phone,
			email: email,
			nickName: nickName,
			fullName: fullName,
			organizationCode: organizationCode,
			organizationName: organizationName,
			rootOrganizationCode: rootOrganizationCode,
			rootOrganizationName: rootOrganizationName,
			authorityGroups: authorityGroups,
			bindDevices: bindDevices,
			lastIP: lastIP,
			logintimes: logintimes,
			userState: userState,
			roleCodes: roleCodes,
			rankCodes: rankCodes,
			positionCodes: positionCodes,
			applyState: applyState,
			rankName: rankName,
			positionName: positionName,
			isDirector: isDirector,
			fieldList: fieldList,
			deletePatientCodes: deletePatientCodes,
			isBatchExportDiagnoseData: isBatchExportDiagnoseData,
			bindAssistantUserCode: bindAssistantUserCode,
			bindAssistantDoctorUserCode: bindAssistantDoctorUserCode,
			loginLockInfo: loginLockInfo,
			signature: signature,
			language: language,
			enableReportLabel: enableReportLabel,
			userCode: userCode,
			userName: userName,
			headImageUrl: headImageUrl,
			createTime: createTime,
			updateTime: updateTime,
		);

	factory UserInfoByCodeDTO.fromJson(Map<String, dynamic> map) {
		return UserInfoByCodeDTO( 
			bindAssistantUserName: map['BindAssistantUserName'],
			bindAssistantDoctorUserName: map['BindAssistantDoctorUserName'],
			phone: map['Phone'],
			email: map['Email'],
			nickName: map['NickName'],
			fullName: map['FullName'],
			organizationCode: map['OrganizationCode'],
			organizationName: map['OrganizationName'],
			rootOrganizationCode: map['RootOrganizationCode'],
			rootOrganizationName: map['RootOrganizationName'],
			authorityGroups: map['AuthorityGroups'] != null ? map['AuthorityGroups'].cast<String>().toList() : null,
			bindDevices: map['BindDevices'] != null ? map['BindDevices'].cast<String>().toList() : null,
			lastIP: map['LastIP'],
			logintimes: map['Logintimes'],
			userState: UserInfoStateEnum.values.firstWhere((e) => e.index == map['UserState']),
			roleCodes: map['RoleCodes'] != null ? map['RoleCodes'].cast<String>().toList() : null,
			rankCodes: map['RankCodes'] != null ? map['RankCodes'].cast<String>().toList() : null,
			positionCodes: map['PositionCodes'] != null ? map['PositionCodes'].cast<String>().toList() : null,
			applyState: ApplyStateEnum.values.firstWhere((e) => e.index == map['ApplyState']),
			rankName: map['RankName'],
			positionName: map['PositionName'],
			isDirector: map['IsDirector'],
			fieldList: map['FieldList'] != null ? map['FieldList'].cast<String>().toList() : null,
			deletePatientCodes: map['DeletePatientCodes'] != null ? map['DeletePatientCodes'].cast<String>().toList() : null,
			isBatchExportDiagnoseData: map['IsBatchExportDiagnoseData'],
			bindAssistantUserCode: map['BindAssistantUserCode'],
			bindAssistantDoctorUserCode: map['BindAssistantDoctorUserCode'],
			loginLockInfo: map['LoginLockInfo'] != null ? LoginLockInfoDTO.fromJson(map['LoginLockInfo']) : null,
			signature: map['Signature'],
			language: map['Language'],
			enableReportLabel: map['EnableReportLabel'],
			userCode: map['UserCode'],
			userName: map['UserName'],
			headImageUrl: map['HeadImageUrl'],
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(bindAssistantUserName != null)
			map['BindAssistantUserName'] = bindAssistantUserName;
		if(bindAssistantDoctorUserName != null)
			map['BindAssistantDoctorUserName'] = bindAssistantDoctorUserName;
		return map;
	}
}

class GetUserByCodeRequest extends TokenRequest{
	String? userCode;

	GetUserByCodeRequest({
		this.userCode,
		String? token,
	}) : super(
			token: token,
		);

	factory GetUserByCodeRequest.fromJson(Map<String, dynamic> map) {
		return GetUserByCodeRequest( 
			userCode: map['UserCode'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(userCode != null)
			map['UserCode'] = userCode;
		return map;
	}
}

enum CommonSettingsEnum {
	Signature,
	Language,
	EnableReportLabel,
}

class CommonSettingsRequest extends TokenRequest{
	CommonSettingsEnum settingType;
	String? value;

	CommonSettingsRequest({
		this.settingType = CommonSettingsEnum.Signature,
		this.value,
		String? token,
	}) : super(
			token: token,
		);

	factory CommonSettingsRequest.fromJson(Map<String, dynamic> map) {
		return CommonSettingsRequest( 
			settingType: CommonSettingsEnum.values.firstWhere((e) => e.index == map['SettingType']),
			value: map['Value'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['SettingType'] = settingType.index;
		if(value != null)
			map['Value'] = value;
		return map;
	}
}

class RefreshStaticticRecordsRequest {
	String? userCode;
	bool inExecutor;

	RefreshStaticticRecordsRequest({
		this.userCode,
		this.inExecutor = false,
	});

	factory RefreshStaticticRecordsRequest.fromJson(Map<String, dynamic> map) {
		return RefreshStaticticRecordsRequest( 
			userCode: map['UserCode'],
			inExecutor: map['InExecutor'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(userCode != null)
			map['UserCode'] = userCode;
		map['InExecutor'] = inExecutor;
		return map;
	}
}

enum ScheduleTypeEnum {
	Consultation,
	Training,
}

class ClientScheduleDTO {
	String? title;
	TransactionStatusEnum status;
	ScheduleTypeEnum scheduleType;
	DateTime? startTime;
	DateTime? endTime;
	String? relevanceCode;

	ClientScheduleDTO({
		this.title,
		this.status = TransactionStatusEnum.Applied,
		this.scheduleType = ScheduleTypeEnum.Consultation,
		this.startTime,
		this.endTime,
		this.relevanceCode,
	});

	factory ClientScheduleDTO.fromJson(Map<String, dynamic> map) {
		return ClientScheduleDTO( 
			title: map['Title'],
			status: TransactionStatusEnum.values.firstWhere((e) => e.index == map['Status']),
			scheduleType: ScheduleTypeEnum.values.firstWhere((e) => e.index == map['ScheduleType']),
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			relevanceCode: map['RelevanceCode'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = Map<String, dynamic>();
		if(title != null)
			map['Title'] = title;
		map['Status'] = status.index;
		map['ScheduleType'] = scheduleType.index;
		if(startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if(endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		if(relevanceCode != null)
			map['RelevanceCode'] = relevanceCode;
		return map;
	}
}

class FindSchedulesRequest extends TokenRequest{
	DateTime? startTime;
	DateTime? endTime;

	FindSchedulesRequest({
		this.startTime,
		this.endTime,
		String? token,
	}) : super(
			token: token,
		);

	factory FindSchedulesRequest.fromJson(Map<String, dynamic> map) {
		return FindSchedulesRequest( 
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if(endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		return map;
	}
}

enum ApplicantTypeEnum {
	Client,
	Device,
	Management,
	ThirdParty,
	Server,
}

class MessageExtendInfoDTO extends BaseDTO{
	String? messageCode;
	NotificationTypeEnum notificationType;
	String? content;
	DateTime? notifyTime;
	ApplicantTypeEnum receiverType;
	String? relevanceCode;
	bool isReaded;
	DateTime? deliveryTime;
	DateTime? readTime;

	MessageExtendInfoDTO({
		this.messageCode,
		this.notificationType = NotificationTypeEnum.Unknown,
		this.content,
		this.notifyTime,
		this.receiverType = ApplicantTypeEnum.Client,
		this.relevanceCode,
		this.isReaded = false,
		this.deliveryTime,
		this.readTime,
		DateTime? createTime,
		DateTime? updateTime,
	}) : super(
			createTime: createTime,
			updateTime: updateTime,
		);

	factory MessageExtendInfoDTO.fromJson(Map<String, dynamic> map) {
		return MessageExtendInfoDTO( 
			messageCode: map['MessageCode'],
			notificationType: NotificationTypeEnum.values.firstWhere((e) => e.index == map['NotificationType']),
			content: map['Content'],
			notifyTime: map['NotifyTime'] != null ? DateTime.parse(map['NotifyTime']) : null,
			receiverType: ApplicantTypeEnum.values.firstWhere((e) => e.index == map['ReceiverType']),
			relevanceCode: map['RelevanceCode'],
			isReaded: map['IsReaded'],
			deliveryTime: map['DeliveryTime'] != null ? DateTime.parse(map['DeliveryTime']) : null,
			readTime: map['ReadTime'] != null ? DateTime.parse(map['ReadTime']) : null,
			createTime: map['CreateTime'] != null ? DateTime.parse(map['CreateTime']) : null,
			updateTime: map['UpdateTime'] != null ? DateTime.parse(map['UpdateTime']) : null,
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(messageCode != null)
			map['MessageCode'] = messageCode;
		map['NotificationType'] = notificationType.index;
		if(content != null)
			map['Content'] = content;
		if(notifyTime != null)
			map['NotifyTime'] = JsonRpcUtils.dateFormat(notifyTime!);
		map['ReceiverType'] = receiverType.index;
		if(relevanceCode != null)
			map['RelevanceCode'] = relevanceCode;
		map['IsReaded'] = isReaded;
		if(deliveryTime != null)
			map['DeliveryTime'] = JsonRpcUtils.dateFormat(deliveryTime!);
		if(readTime != null)
			map['ReadTime'] = JsonRpcUtils.dateFormat(readTime!);
		return map;
	}
}

enum QueryCMSMessageStatusEnum {
	UnRead,
	Read,
}

class QueryMessageListRequest extends PageRequest{
	QueryCMSMessageStatusEnum status;
	String? keyword;
	DateTime? startTime;
	DateTime? endTime;
	NotificationTypeEnum notificationType;
	String? relevanceCode;

	QueryMessageListRequest({
		this.status = QueryCMSMessageStatusEnum.UnRead,
		this.keyword,
		this.startTime,
		this.endTime,
		this.notificationType = NotificationTypeEnum.Unknown,
		this.relevanceCode,
		int pageIndex = 0,
		int pageSize = 0,
		String? token,
	}) : super(
			pageIndex: pageIndex,
			pageSize: pageSize,
			token: token,
		);

	factory QueryMessageListRequest.fromJson(Map<String, dynamic> map) {
		return QueryMessageListRequest( 
			status: QueryCMSMessageStatusEnum.values.firstWhere((e) => e.index == map['Status']),
			keyword: map['Keyword'],
			startTime: map['StartTime'] != null ? DateTime.parse(map['StartTime']) : null,
			endTime: map['EndTime'] != null ? DateTime.parse(map['EndTime']) : null,
			notificationType: NotificationTypeEnum.values.firstWhere((e) => e.index == map['NotificationType']),
			relevanceCode: map['RelevanceCode'],
			pageIndex: map['PageIndex'],
			pageSize: map['PageSize'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		map['Status'] = status.index;
		if(keyword != null)
			map['Keyword'] = keyword;
		if(startTime != null)
			map['StartTime'] = JsonRpcUtils.dateFormat(startTime!);
		if(endTime != null)
			map['EndTime'] = JsonRpcUtils.dateFormat(endTime!);
		map['NotificationType'] = notificationType.index;
		if(relevanceCode != null)
			map['RelevanceCode'] = relevanceCode;
		return map;
	}
}

class SetMessageDeliveryRequest extends TokenRequest{
	String? messageCode;
	bool isReaded;

	SetMessageDeliveryRequest({
		this.messageCode,
		this.isReaded = false,
		String? token,
	}) : super(
			token: token,
		);

	factory SetMessageDeliveryRequest.fromJson(Map<String, dynamic> map) {
		return SetMessageDeliveryRequest( 
			messageCode: map['MessageCode'],
			isReaded: map['IsReaded'],
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(messageCode != null)
			map['MessageCode'] = messageCode;
		map['IsReaded'] = isReaded;
		return map;
	}
}

class SetMessageInfoReqeust extends TokenRequest{
	List<String >? messageCodes;

	SetMessageInfoReqeust({
		this.messageCodes,
		String? token,
	}) : super(
			token: token,
		);

	factory SetMessageInfoReqeust.fromJson(Map<String, dynamic> map) {
		return SetMessageInfoReqeust( 
			messageCodes: map['MessageCodes'] != null ? map['MessageCodes'].cast<String>().toList() : null,
			token: map['Token'],
		);
	}

	Map<String, dynamic> toJson() {
		final map = super.toJson();
		if(messageCodes != null)
			map['MessageCodes'] = messageCodes;
		return map;
	}
}


